/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (radio_frame)
#endif
#ifdef __GNUC__
static const guint8 radio_frame[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 radio_frame[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (676) */
  "\0\0\2\274"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (52) */
  "\0\0\0""4"
  /* width (13) */
  "\0\0\0\15"
  /* height (13) */
  "\0\0\0\15"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\25\0\0\0t\0\0\0\325\0\0\0\377\0\0\0\325"
  "\0\0\0t\0\0\0\25\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0"
  "\361\0\0\0\225\0\0\0J\0\0\0""2\0\0\0H\0\0\0\224\0\0\0\362\0\0\0[\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0\322\0\0\0""8\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0""4\0\0\0\323\0\0\0[\0\0\0\0\0\0\0\25\0\0\0\360"
  "\0\0\0:\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "6\0\0\0\360\0\0\0\25\0\0\0t\0\0\0\227\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\227\0\0\0t\0\0\0\325\0"
  "\0\0R\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0O\0\0\0\325\0\0\0\377\0\0\0>\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""9\0\0\0\377\0\0"
  "\0\325\0\0\0U\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0P\0\0\0\325\0\0\0t\0\0\0\235\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\234\0\0"
  "\0t\0\0\0\25\0\0\0\363\0\0\0\77\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0:\0\0\0\363\0\0\0\25\0\0\0\0\0\0\0[\0\0\0\332"
  "\0\0\0=\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""9\0\0\0\331\0"
  "\0\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0\364\0\0\0\237\0\0\0S\0\0\0"
  "9\0\0\0O\0\0\0\235\0\0\0\365\0\0\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\25\0\0\0t\0\0\0\325\0\0\0\377\0\0\0\325\0\0\0t\0\0\0\25"
  "\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (radio_inner)
#endif
#ifdef __GNUC__
static const guint8 radio_inner[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 radio_inner[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (676) */
  "\0\0\2\274"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (52) */
  "\0\0\0""4"
  /* width (13) */
  "\0\0\0\15"
  /* height (13) */
  "\0\0\0\15"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4"
  "\0\0\0v\0\0\0\356\0\0\0\377\0\0\0\366\0\0\0\220\0\0\0\12\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0,\0\0\0\337\0\0\0\354\0\0\0z\0\0\0"
  ":\0\0\0g\0\0\0\334\0\0\0\357\0\0\0J\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0"
  "\0\0\337\0\0\0\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\224"
  "\0\0\0\345\0\0\0*\0\0\0\0\0\0\0\0\0\0\0v\0\0\0\354\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\325\0\0\0\223\0\0\0\0\0"
  "\0\0\0\0\0\0\356\0\0\0\203\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0b\0\0\0\350\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0K\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0,\0\0\0\374"
  "\0\0\0\0\0\0\0\0\0\0\0\366\0\0\0y\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0U\0\0\0\357\0\0\0\0\0\0\0\0\0\0\0\220\0\0\0"
  "\341\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\306"
  "\0\0\0\244\0\0\0\0\0\0\0\0\0\0\0\12\0\0\0\360\0\0\0\240\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0v\0\0\0\356\0\0\0""8\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0K\0\0\0\347\0\0\0\331\0\0\0h\0\0\0,\0\0\0T\0\0\0\307\0"
  "\0\0\356\0\0\0n\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0*\0\0\0"
  "\224\0\0\0\350\0\0\0\374\0\0\0\356\0\0\0\244\0\0\0""8\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (radio_light)
#endif
#ifdef __GNUC__
static const guint8 radio_light[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 radio_light[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (676) */
  "\0\0\2\274"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (52) */
  "\0\0\0""4"
  /* width (13) */
  "\0\0\0\15"
  /* height (13) */
  "\0\0\0\15"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0!\0"
  "\0\0`\0\0\0\377\0\0\0\377\0\0\0\206\0\0\0`\0\0\0!\0\0\0\4\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\4\0\0\0;\0\0\0\377\0\0\0\206\0\0\0\77\0\0\0%\0\0\0"
  ">\0\0\0\206\0\0\0R\0\0\0\5\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0!\0\0\0\377\0"
  "\0\0Y\0\0\0\14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\0\0\0\3\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0`\0\0\0\206\0\0\0\14\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0"
  "\0\0D\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0-\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\206"
  "\0\0\0F\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0`\0\0\0{\0\0\0\12\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0!\0"
  "\0\0""4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (radio_on)
#endif
#ifdef __GNUC__
static const guint8 radio_on[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 radio_on[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (676) */
  "\0\0\2\274"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (52) */
  "\0\0\0""4"
  /* width (13) */
  "\0\0\0\15"
  /* height (13) */
  "\0\0\0\15"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0l\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0H\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0l\0\0\0l\0\0\0U\0\0\0\310\0"
  "\0\0\310\0\0\0\332\0\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\310\0\0\0U\0\0\0\310\0\0\0\310\0\0\0\310\0\0\0\332\0\0\0\310"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\332\0\0\0\310"
  "\0\0\0\310\0\0\0\310\0\0\0\310\0\0\0\332\0\0\0\332\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0\310"
  "\0\0\0\332\0\0\0\332\0\0\0\310\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0H\0\0\0\332\0\0\0\332\0\0\0\332\0\0\0\332\0\0\0\332\0"
  "\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0H"
  "\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (check_on)
#endif
#ifdef __GNUC__
static const guint8 check_on[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 check_on[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (324) */
  "\0\0\1\\"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (36) */
  "\0\0\0$"
  /* width (9) */
  "\0\0\0\11"
  /* height (9) */
  "\0\0\0\11"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40\0\0\0\270\0"
  "\0\0\307\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\37\0\0\0\341\0"
  "\0\0\331\0\0\0\0\0\0\0!\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\33\0\0\0\320\0\0"
  "\0\367\0\0\0\36\0\0\0\0\0\0\0\352\0\0\0\371\0\0\0\210\0\0\0\0\0\0\0o"
  "\0\0\0\374\0\0\0\223\0\0\0\0\0\0\0\0\0\0\0k\0\0\0\372\0\0\0\373\0\0\0"
  "a\0\0\0\356\0\0\0\366\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\214\0\0\0"
  "\373\0\0\0\372\0\0\0\374\0\0\0\251\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\321\0\0\0\374\0\0\0\371\0\0\0\36\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0%\0\0\0\366\0\0\0\321\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0d\0\0\0P\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (slider)
#endif
#ifdef __GNUC__
static const guint8 slider[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 slider[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1092) */
  "\0\0\4\\"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (84) */
  "\0\0\0T"
  /* width (21) */
  "\0\0\0\25"
  /* height (13) */
  "\0\0\0\15"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\25\0\0\0t\0\0\0\325\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\325\0\0\0t\0\0\0\25\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0[\0\0\0\361\0\0\0\225\0\0\0J\0\0\0""2\0\0\0""2\0\0\0""2\0\0\0""2"
  "\0\0\0""2\0\0\0""2\0\0\0""2\0\0\0""2\0\0\0""2\0\0\0H\0\0\0\224\0\0\0"
  "\362\0\0\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0\322\0\0\0""8\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""4\0\0\0\323\0\0\0[\0\0\0\0\0\0\0"
  "\25\0\0\0\360\0\0\0:\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0""6\0\0\0\360\0\0\0\25\0\0\0\263\0\0\0\227\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\227\0\0\0"
  "\263\0\0\0\325\0\0\0R\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0R\0\0\0\325\0\0\0\377\0\0\0>\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0>\0\0\0\377"
  "\0\0\0\325\0\0\0U\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0U\0\0\0\325\0\0\0\263\0\0\0\235\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\235\0\0\0"
  "\263\0\0\0\25\0\0\0\363\0\0\0\77\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0:\0\0\0\363\0\0\0\25\0\0\0\0\0\0\0[\0\0\0\332\0"
  "\0\0=\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""9\0\0\0\331\0\0\0[\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0\364\0\0\0\237\0\0\0S\0\0\0""9\0\0"
  "\0""9\0\0\0""9\0\0\0""9\0\0\0""9\0\0\0""9\0\0\0""9\0\0\0""9\0\0\0""9"
  "\0\0\0O\0\0\0\235\0\0\0\365\0\0\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\25\0\0\0t\0\0\0\325\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\325\0\0"
  "\0t\0\0\0\25\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (slider_light)
#endif
#ifdef __GNUC__
static const guint8 slider_light[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 slider_light[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1092) */
  "\0\0\4\\"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (84) */
  "\0\0\0T"
  /* width (21) */
  "\0\0\0\25"
  /* height (13) */
  "\0\0\0\15"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0!\0\0\0"
  "`\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0`\0\0\0!\0\0\0\4\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0;\0\0\0\377\0\0\0\206\0\0\0\77\0\0\0"
  "%\0\0\0%\0\0\0%\0\0\0%\0\0\0%\0\0\0%\0\0\0%\0\0\0%\0\0\0%\0\0\0\77\0"
  "\0\0\206\0\0\0\377\0\0\0;\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0!\0\0\0\377\0"
  "\0\0Y\0\0\0\14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\14\0\0\0Y\0\0\0Y\0\0\0!\0\0"
  "\0\0\0\0\0\0\0\0\0`\0\0\0\206\0\0\0\14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0D\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\0\0\0-\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\206\0\0\0F\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0`\0\0\0{\0\0\0\12\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0!\0\0\0""4\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\4\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (check_x_on)
#endif
#ifdef __GNUC__
static const guint8 check_x_on[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 check_x_on[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (324) */
  "\0\0\1\\"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (36) */
  "\0\0\0$"
  /* width (9) */
  "\0\0\0\11"
  /* height (9) */
  "\0\0\0\11"
  /* pixel_data: */
  "\0\0\0|\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0\324\0\0"
  "\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0\0\0\324\0\0"
  "\0\324\0\0\0\324\0\0\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\324"
  "\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0\0\0\324\0\0\0\324\0\0\0"
  "\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0"
  "\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0"
  "\324\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0"
  "\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0"
  "\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0\0\0\324\0\0"
  "\0\324\0\0\0\324\0\0\0|\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0|\0\0\0\324\0\0\0|"};


